==> downloads.html?file=gigkalender_v1.2.63_076.zip: gigkalender/admin/setup.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline04.'</p>';
  if ( !IsUserAdmin() ) { echo $L_015; }
  else
  {
    // Inhalt hier einfügen
    echo '<form id="Setup" method="post" action="index.php?submenue=admin&amp;inhalt=updateSetup">
            <table class="Table_Setup" summary="Table_Setup">
              <!-- Backend -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_067.':</td>
              </tr>';
              include ('includes/setup/SetupRefreshtime.php');
              include ('includes/setup/SetupExportSeparator.php');
              include ('includes/setup/SetupUserMaximumInactivityTime.php');
              echo '
              <!-- Kalender -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_202.':</td>
              </tr>';
              include ('includes/setup/SetupAllowDoubleDates.php');
              include ('includes/setup/SetupRowsTextareas.php');
              include ('includes/setup/SetupShowEditorInAddGigForm.php');
              include ('includes/setup/SetupCalendarAttributeInAddGigForm.php');
              echo '
              <!-- FRONTEND -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_Frontend.':</td>
              </tr>';
              include ('includes/setup/SetupFrontendCalendarShowMonthlySeparator.php');
              include ('includes/setup/SetupFrontendCalendarShowTableHeads.php');
              include ('includes/setup/SetupFrontendAllowOptionalGigs.php');
              include ('includes/setup/SetupFrontendAllowPrivateGigs.php');
              include ('includes/setup/SetupFrontendCalendarSelector.php');
              include ('includes/setup/SetupFrontendLanguage.php');
              include ('includes/setup/SetupFrontendCalendarPeriodSelector.php');
              include ('includes/setup/SetupFrontendCalendarCharsInFields.php');
              include ('includes/setup/SetupFrontendCalendarMaxAmountOfGigs.php');
              include ('includes/setup/SetupFrontendAttributes.php');
              include ('includes/setup/SetupFrontendDetailAttributes.php');
              echo '
              <!-- Gaestebuch -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_110.':</td>
              </tr>';
              include ('includes/setup/SetupGuestbookEntriesPerPage.php');
              include ('includes/setup/SetupGuestbookMail.php');
              include ('includes/setup/SetupGuestbookSpamDomains.php');
              include ('includes/setup/SetupGuestbookSpamIPs.php');
              include ('includes/setup/SetupGuestbookSpamWords.php');
              echo '
              <!-- NEWS -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_175.':</td>
              </tr>';
              include ('includes/setup/SetupNewsEntriesPerPage.php');
              include ('includes/setup/SetupNewsChannelTitle.php');
              include ('includes/setup/SetupNewsChannelURL.php');
              include ('includes/setup/SetupNewsChannelDescription.php');
              include ('includes/setup/SetupNewsChannelLanguage.php');
              include ('includes/setup/SetupNewsChannelCopyright.php');
              echo '
              <tr>
                <td>&nbsp;</td>
           	    <td>
                  <input type="submit" name="Submit" value="'.$L_Button01.'" class="button" />
                  <input type="reset" value="'.$L_Button38.'" class="button" />
                  <input type="hidden" name="gesendet" value="1" />
                  <input type="hidden" name="http-equiv" value="setup" />
                </td>
              </tr>
            </table>
          </form>';
    // Inhalt zuende
  }
?>

==> downloads.html?file=gigkalender_v1.2.65_009.zip: gigkalender/admin/setup.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline04.'</p>';
  if ( !IsUserAdmin() ) { echo $L_015; }
  else
  {
    // Inhalt hier einfügen
    echo '<form id="Setup" method="post" action="index.php?submenue=admin&amp;inhalt=updateSetup" accept-charset="UTF-8">
            <table class="Table_Setup" summary="Table_Setup">
              <!-- Backend -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_067.':</td>
              </tr>';
              include ('includes/setup/SetupRefreshtime.php');
              include ('includes/setup/SetupExportSeparator.php');
              include ('includes/setup/SetupUserMaximumInactivityTime.php');
              echo '
              <!-- Kalender -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_202.':</td>
              </tr>';
              include ('includes/setup/SetupAllowDoubleDates.php');
              include ('includes/setup/SetupRowsTextareas.php');
              include ('includes/setup/SetupShowEditorInAddGigForm.php');
              include ('includes/setup/SetupCalendarAttributeInAddGigForm.php');
              echo '
              <!-- FRONTEND -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_Frontend.':</td>
              </tr>';
              include ('includes/setup/SetupFrontendCalendarShowMonthlySeparator.php');
              include ('includes/setup/SetupFrontendCalendarShowTableHeads.php');
              include ('includes/setup/SetupFrontendAllowOptionalGigs.php');
              include ('includes/setup/SetupFrontendAllowPrivateGigs.php');
              include ('includes/setup/SetupFrontendCalendarSelector.php');
              include ('includes/setup/SetupFrontendLanguage.php');
              include ('includes/setup/SetupFrontendCalendarPeriodSelector.php');
              include ('includes/setup/SetupFrontendCalendarCharsInFields.php');
              include ('includes/setup/SetupFrontendCalendarMaxAmountOfGigs.php');
              include ('includes/setup/SetupFrontendAttributes.php');
              include ('includes/setup/SetupFrontendDetailAttributes.php');
              echo '
              <!-- Gaestebuch -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_110.':</td>
              </tr>';
              include ('includes/setup/SetupGuestbookEntriesPerPage.php');
              include ('includes/setup/SetupGuestbookMail.php');
              include ('includes/setup/SetupGuestbookSpamDomains.php');
              include ('includes/setup/SetupGuestbookSpamIPs.php');
              include ('includes/setup/SetupGuestbookSpamWords.php');
              echo '
              <!-- NEWS -->
              <tr>
                <td colspan="2" class="TabelleSetupSubTitles">'.$L_175.':</td>
              </tr>';
              include ('includes/setup/SetupNewsEntriesPerPage.php');
              include ('includes/setup/SetupNewsChannelTitle.php');
              include ('includes/setup/SetupNewsChannelURL.php');
              include ('includes/setup/SetupNewsChannelDescription.php');
              include ('includes/setup/SetupNewsChannelLanguage.php');
              include ('includes/setup/SetupNewsChannelCopyright.php');
              echo '
              <tr>
                <td>&nbsp;</td>
           	    <td>
                  <input type="submit" name="Submit" value="'.$L_Button01.'" class="button" />
                  <input type="reset" value="'.$L_Button38.'" class="button" />
                  <input type="hidden" name="gesendet" value="1" />
                  <input type="hidden" name="http-equiv" value="setup" />
                </td>
              </tr>
            </table>
          </form>';
    // Inhalt zuende
  }
?>
